%define major            8
%define intllibname      %mklibname intl %{major}
%define misclibname      %mklibname gettextmisc

%define textstylemajor   0
%define textstylelibname %mklibname textstyle %{textstylemajor}

%bcond_with bootstrap
%bcond_with check
%bcond_with java
%bcond_with csharp

%define versi	%(echo %{version} | cut -d. -f1-3)

Name:		gettext
Summary:	GNU libraries and utilities for producing multi-lingual messages
Version:	0.22.5
Release:	%mkrel 5
License:	GPLv3+ and LGPLv2+ and GFDL
Group:		System/Internationalization
URL:		https://www.gnu.org/software/gettext/
Source:		https://ftp.gnu.org/pub/gnu/%{name}/%{name}-%{version}.tar.xz
Source1:	https://ftp.gnu.org/pub/gnu/%{name}/%{name}-%{version}.tar.xz.sig
Source2:	po-mode-init.el
Patch0:		gettext-0.20.1-unescaped-left-brace.patch
# from fedora
Patch11:	gettext-0.21.1-covscan.patch
Patch12:	gettext-0.22-disable-libtextstyle.patch
# https://lists.gnu.org/archive/html/bug-gettext/2020-08/msg00026.html
# CVE-2020-12825
Patch20:	0001-Backport-libcroco-upstream-merge-request-parser-limi.patch
%if %{with csharp}
BuildRequires:	mono
%endif
%if %{with java}
BuildRequires:	eclipse-ecj
BuildRequires:	gcc-java
BuildRequires:	gcj-tools
BuildRequires:	fastjar
%endif
BuildRequires:	automake
BuildRequires:	bison
BuildRequires:	diffutils
BuildRequires:	flex
BuildRequires:	texinfo
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	libgomp-devel
# not necessary best way to do it but without gettext-devel
# the bootstrap game is lost
%if !%{with bootstrap}
BuildRequires:	emacs-bin
BuildRequires:	pkgconfig(libxml-2.0)
%endif
BuildRequires:	unistring-devel
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(libacl)
# test suite
BuildRequires:	locales-fa
BuildRequires:	locales-fr
BuildRequires:	locales-ja
BuildRequires:	locales-zh
BuildRequires:	gawk >= 4.2.1

# see mga#27108
Provides:	bundled(libcroco) = 0.6.13

Requires:	%{name}-base = %{version}
Requires:	%{misclibname} = %{version}
Obsoletes:	%textstylelibname < %{version}-%{release}

%description
The GNU gettext package provides a set of tools and documentation for producing
multi-lingual messages in programs. Tools include a set of conventions about
how programs should be written to support message catalogs, a directory and
file naming organization for the message catalogs, a runtime library which
supports the retrieval of translated messages, and stand-alone programs for
handling the translatable and the already translated strings. Gettext provides
an easy to use library and tools for creating, using, and modifying natural
language catalogs and is a powerful and simple method for internationalizing
programs.

If you would like to internationalize or incorporate multi-lingual messages
into programs that you're developing, you should install gettext.

Build Option:
--with csharp          Enables C# support in gettext
--without java         Disables Java support in gettext

%package -n	autopoint
Group:		Development/Other
Summary:	Tool for setting up gettext infrastructure in a source package
# autopoint archive
License:	GPLv3+
# /usr/bin/autopoint: line 677: cmp: command not found
Requires:	diffutils
Conflicts:	gettext-devel < 0.21-9

%description -n	autopoint
The 'autopoint' program copies standard gettext infrastructure files into a
source package. It extracts from a macro call of the form
'AM_GNU_GETTEXT_VERSION(VERSION)', found in the package's 'configure.in' or
'configure.ac' file, the gettext version used by the package, and copies the
infrastructure files belonging to this version into the package.

%package -n	%{intllibname}
Summary:	Basic libintl library for internationalization
Group:		System/Libraries
License:	LGPLv2+
Requires(pre):	filesystem >= 2.1.9-18
Provides:	libintl = %{version}-%{release}

%description -n	%{intllibname}
This package contains the libintl library, which is important for
system internationalization.

%package -n	%{misclibname}
Summary:	Other %{name} libraries needed by %{name} utilities
Group:		System/Libraries
License:	LGPLv2+
Provides:	libgettextmisc

%description -n	%{misclibname}
This package contains all other libraries used by %{name} utilities,
and are not very widely used outside %{name}.

%package	devel
Summary:	Development files for %{name}
Group:		Development/C
# libasprintf is LGPLv2+
# libgettextpo is GPLv3+
License:	LGPLv2+ and GFDL
Requires:	%{name} = %{version}
Requires:	autopoint = %{version}

%description	devel
This package contains all development related files necessary for
developing or compiling applications/libraries that needs
internationalization capability. You also need this package if you
want to add gettext support for your project.

%package	base
Summary:	Basic binary for showing translation of textual messages
Group:		System/Internationalization
Requires(pre):	filesystem >= 2.1.9-18
Requires:	%{intllibname} = %{version}

# see mga#26216
Conflicts:	gettext < 0.20.1-3

%description	base
This package contains the basic binary from %{name}. It is split from
%{name} because initscript needs it to show translated boot messages.

%if %{with java}
%package	java
Summary:	Java binding for GNU gettext
Group:		System/Internationalization
Requires:	%{name} = %{version}

%description	java
This package contains class file that implements the main GNU libintl
functions in Java. This allows compiling GNU gettext message catalogs
into Java ResourceBundle classes.
%endif

%if %{with csharp}
%package	csharp
Summary:	C# binding for GNU gettext
Group:		System/Internationalization
Requires:	mono

%description	csharp
This package contains class file that implements the main GNU libintl
functions in C#. This allows compiling GNU gettext message catalogs
into C# dll or resource files.
%endif

%prep
%autosetup -p1

%if !%{with bootstrap}
# Defeat libtextstyle attempt to bundle libglib and libxml2.  The
# comments indicate this is done because the libtextstyle authors do not want
# applications using their code to suffer startup delays due to the relocations
# in the two libraries.  This is not a sufficient reason for Mageia.
#
# ovitters: do use bundled libcroco as it is unmaintained upstream and has
# several security bugs, see mga#27108
rm -rf libtextstyle/lib/{glib,libxml}
for l in LIBGLIB LIBXML; do
  sed -i -e "s,\(gl_$l(\[\).*\(\])\),\1no\2,g" $(grep -rl -e "gl_$l(\[.*\])")
done
%endif

%build
autoreconf -fi

%if %{with java}
export GCJ="%{_bindir}/gcj"
export JAVAC="%{_bindir}/gcj -C"
export JAR="%{_bindir}/fastjar"
%endif

%configure \
	--enable-shared \
	--disable-static \
	--disable-rpath \
	--with-included-gettext \
	--with-included-libcroco \
%if %{with csharp}
	--enable-csharp=mono \
%else
	--disable-csharp \
%endif
%if ! %{with java}
	--disable-java \
%endif


# Eliminate hardcoded rpaths; workaround libtool reordering -Wl,--as-needed
# after all the libraries.
sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    -e 's|CC=.g..|& -Wl,--as-needed|' \
    -i $(find . -name libtool)

%make_build

%if %{with check}
%check
export JAVAC=ecj
# this takes quite a lot of time to run

# adapt to rpath removal
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}:$PWD/gettext-tools/intl/.libs

# override LIBUNISTRING to prevent reordering of lib objects
LC_ALL=UTF-8 make check LIBUNISTRING=-lunistring
%endif

%install
%make_install

# remove unwanted files
rm -f %{buildroot}%{_includedir}/libintl.h \
      %{buildroot}%{_datadir}/locale/locale.alias
rm -f gettext-runtime/intl-java/javadoc2/package-list

install -D -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/emacs/site-start.d/%{name}.el

# remove non-standard lc directories
for i in en@boldquot en@quot ; do rm -rf %{buildroot}/%{_datadir}/locale/$i; done

# move installed doc back to %%doc
rm -rf htmldoc examples
mkdir htmldoc
for i in gettext-runtime/man/*.html; do
  rm -f %{buildroot}%{_datadir}/doc/gettext/`basename $i`
done
rm -rf %{buildroot}%{_datadir}/doc/gettext/javadoc*

# remove java stuff, otherwise rpm complains
%if !%{with java}
rm -f %{buildroot}%{_libdir}/%{name}/gnu.gettext.* \
      %{buildroot}%{_datadir}/%{name}/*.jar
%endif

# don't ship .la
find %{buildroot} -name '*.la' -delete

# fix rights
chmod 755 %{buildroot}%{_libdir}/$(readlink %{buildroot}%{_libdir}/libintl.so)

rm -fr %{buildroot}/usr/share/doc/{libasprintf/autosprintf_all.html,gettext/examples}

%find_lang %{name} --all-name

%files
%doc AUTHORS README COPYING gettext-runtime/ABOUT-NLS gettext-runtime/BUGS NEWS THANKS 
%config(noreplace) %{_sysconfdir}/emacs/site-start.d/*.el
%{_bindir}/envsubst
%{_bindir}/gettext.sh
%{_bindir}/msg*
%{_bindir}/recode-sr-latin
%{_bindir}/xgettext
%dir %{_datadir}/gettext
%{_datadir}/%{name}/msgunfmt.tcl
%{_datadir}/%{name}/projects
%{_datadir}/%{name}/javaversion.class
%{_datadir}/%{name}/styles
%dir %{_datadir}/%{name}-%{versi}
%{_datadir}/%{name}-%{versi}/its
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/cldr-plurals
%{_libdir}/%{name}/hostname
%{_libdir}/%{name}/project-id
%{_libdir}/%{name}/urlget
%{_libdir}/%{name}/user-email
%if %{with java}
%exclude %{_libdir}/%{name}/gnu.gettext.*
%endif
%{_infodir}/gettext.*
%if !%{with bootstrap}
%{_datadir}/emacs/site-lisp/*.el*
%endif
%{_mandir}/man1/envsubst.*
%{_mandir}/man1/msg*
%{_mandir}/man1/xgettext.*
%{_mandir}/man1/recode-sr-latin.*

%files base -f %{name}.lang
%doc gettext-runtime/man/*.1.html
%{_bindir}/gettext
%{_bindir}/ngettext
%{_mandir}/man1/gettext*
%{_mandir}/man1/ngettext*

%files -n %{intllibname}
%doc gettext-runtime/intl/COPYING*
%{_libdir}/libintl.so.%{major}
%{_libdir}/libintl.so.%{major}.*

%files -n %{misclibname}
%doc gettext-runtime/intl/COPYING*
%{_libdir}/libgettext*-*.*.so
%{_libdir}/libgettext*.so.*
%{_libdir}/libasprintf*.so.*

%files -n autopoint
%{_bindir}/autopoint
%{_datadir}/%{name}/archive.dir.tar.xz
%{_mandir}/man1/autopoint.1*

%files devel
%doc gettext-runtime/man/*.3.html htmldoc
%doc /usr/share/doc/gettext/*.html
%doc /usr/share/doc/gettext/*/*.html
%{_bindir}/gettextize
%{_datadir}/%{name}/ABOUT-NLS
%{_datadir}/%{name}/config.rpath
%{_datadir}/%{name}/*.h
%{_datadir}/%{name}/po
%{_datadir}/aclocal/*
%{_includedir}/*
%{_infodir}/autosprintf*
# "lib*.so" cannot be used (it should be 'lib[^\.]*\.so' regexp in fact
# but using regexp is not possible here; so we list all files manually
%{_libdir}/libasprintf.so
%{_libdir}/libgettextlib.so
%{_libdir}/libgettextpo.so
%{_libdir}/libgettextsrc.so
%{_libdir}/libintl.so
%{_mandir}/man3/*

%if %{with java}
%files java
%doc gettext-runtime/intl-java/javadoc*
%{_libdir}/%{name}/gnu.gettext.*
%{_datadir}/%{name}/*.jar
%endif

%if %{with csharp}
%files csharp
%doc gettext-runtime/intl-csharp/csharpdoc/*
%{_libdir}/*.dll
%{_libdir}/gettext/*.exe
%endif


%changelog
* Mon Jul 07 2025 umeabot <umeabot> 0.22.5-5.mga10
+ Revision: 2248175
- Mageia 10 Mass Rebuild

* Sun Mar 16 2025 wally <wally> 0.22.5-4.mga10
+ Revision: 2164802
- rebuild for libxml2 2.13.6

* Fri Apr 05 2024 wally <wally> 0.22.5-3.mga10
+ Revision: 2054861
- another rebuild due to a BS hickup

* Fri Apr 05 2024 wally <wally> 0.22.5-2.mga10
+ Revision: 2054615
- basesystem rebuild for i686

* Wed Mar 06 2024 daviddavid <daviddavid> 0.22.5-1.mga10
+ Revision: 2048044
- new version: 0.22.5

* Thu Jan 12 2023 daviddavid <daviddavid> 0.21.1-2.mga9
+ Revision: 1932546
- rebuild for new libunistring 1.1

* Tue Oct 11 2022 luigiwalser <luigiwalser> 0.21.1-1.mga9
+ Revision: 1896310
- 0.21.1
- rediff patch 1

* Wed Apr 06 2022 tv <tv> 0.21-10.20220203.mga9
+ Revision: 1846486
- Update to gettext-snapshot-20220228 in order to fix build
- Disable libtextstyle as it is dependent on libcroco, which is unmaintained now
- Disable testsuite due to one failure (xgettext-its-2)
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ wally <wally>
- fix devel pkg license after autopoint split out

* Sun May 02 2021 wally <wally> 0.21-9.mga9
+ Revision: 1720935
- split out autopoint from devel pkg to not pull a ton of devel pkgs with autoconf

* Sat Dec 12 2020 neoclust <neoclust> 0.21-8.mga8
+ Revision: 1655966
- Add upstream patch to fix tests

* Sat Dec 12 2020 neoclust <neoclust> 0.21-7.mga8
+ Revision: 1655881
- Rebuild for armv7

* Fri Dec 11 2020 wally <wally> 0.21-6.mga8
+ Revision: 1655448
- fix build with autoconf 2.70

* Fri Nov 06 2020 wally <wally> 0.21-5.mga8
+ Revision: 1643109
- fix build with autoconf 2.69d

* Tue Oct 13 2020 wally <wally> 0.21-4.mga8
+ Revision: 1635498
- force bundled libcroco usage

* Tue Oct 13 2020 wally <wally> 0.21-3.mga8
+ Revision: 1635421
- backport fixes from upstream libcroco merge request to fix CVE-2020-12825 in bundled libcroco

* Tue Oct 13 2020 ovitters <ovitters> 0.21-2.mga8
+ Revision: 1635404
- Bundle libcroco so we can remove the system package as per Fedora (mga#27108)

* Thu Jul 30 2020 wally <wally> 0.21-1.mga8
+ Revision: 1609915
- new version 0.21
- drop extra libtextstyle source and hacks

* Sun Jul 26 2020 wally <wally> 0.20.2-4.mga8
+ Revision: 1609080
- bundle intermediate libtextstyle 0.25.0 needed by bison 3.7
- add patch from OpenEmbedded to use pkg-conf to find system libs for libtextstyle

* Thu May 21 2020 wally <wally> 0.20.2-3.mga8
+ Revision: 1586728
- make devel pkg require diffutils for autopoint

* Fri Apr 24 2020 wally <wally> 0.20.2-2.mga8
+ Revision: 1571716
- properly build with system libcroco and libxml2

* Tue Apr 14 2020 daviddavid <daviddavid> 0.20.2-1.mga8
+ Revision: 1567351
- new version: 0.20.2
- remove merged upstream patches

* Wed Feb 19 2020 daviddavid <daviddavid> 0.20.1-4.mga8
+ Revision: 1544943
- add conflict to ease upgrade (mga#26216)

* Wed Feb 19 2020 pterjan <pterjan> 0.20.1-3.mga8
+ Revision: 1544473
- Fix duplicate ngettext added when updating to 0.20.1, it causes conflicts when the package gets updated/rebuilt

* Tue Feb 18 2020 umeabot <umeabot> 0.20.1-2.mga8
+ Revision: 1542013
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Jan 04 2020 luigiwalser <luigiwalser> 0.20.1-1.mga8
+ Revision: 1475912
- 0.20.1
- replace patch 1 with updated patch 0 to fix the same issue
- remove upstreamed patches 11 and 20
- update paths in patch 10
- add patch 1 from fedora to fix misbehavior of msgmerge --for-msgfmt
- add new libtextstylemajor subpackage
- update License tags
- update Source URLs
- do not bundle libcroco and libxml2 (from fedora)
- remove hardcoded rpaths (from fedora)

* Fri May 31 2019 shlomif <shlomif> 0.19.8.1-5.mga7
+ Revision: 1399419
- fix an xgettext --its crash
+ wally <wally>
- add patch from upstream to fix 'Unescaped left brace in regex is deprecated here' warnings in texi2html with perl 5.26

* Thu Nov 15 2018 ns80 <ns80> 0.19.8.1-4.mga7
+ Revision: 1330014
- add patch from Ubuntu for CVE-2018-18751 (mga#23843)

* Mon Sep 03 2018 tv <tv> 0.19.8.1-3.mga7
+ Revision: 1256393
- rely on filetriggers for info system (mga#23482)
+ kekepower <kekepower>
- Use new make macros
+ wally <wally>
- make devel pkg to provide autopoint

* Mon Feb 26 2018 wally <wally> 0.19.8.1-2.mga7
+ Revision: 1205273
- rebuild with new gawk to see if tests still fails

* Sat Jun 11 2016 luigiwalser <luigiwalser> 0.19.8.1-1.mga6
+ Revision: 1021205
- 0.19.8.1
- libintl major is back to 8 again
- 0.19.8
- libintl major is now 9

* Mon Mar 14 2016 wally <wally> 0.19.7-2.mga6
+ Revision: 990598
- run checks with UTF-8 locale
- don't require cvs as it's not needed anymore

* Mon Dec 28 2015 fwang <fwang> 0.19.7-1.mga6
+ Revision: 916324
- update file list
- drop requires on expat as upstream chages
- 0.19.7

* Thu Dec 24 2015 fwang <fwang> 0.19.6-1.mga6
+ Revision: 914464
- 0.19.6
- 0.19.5.1
+ tmb <tmb>
- rebuild for new gcc

* Fri Dec 26 2014 luigiwalser <luigiwalser> 0.19.4-1.mga5
+ Revision: 806137
- 0.19.4

* Fri Oct 17 2014 luigiwalser <luigiwalser> 0.19.3-1.mga5
+ Revision: 769118
- 0.19.3
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.19.2-3.mga5
+ Revision: 679550
- Mageia 5 Mass Rebuild

* Wed Sep 03 2014 luigiwalser <luigiwalser> 0.19.2-2.mga5
+ Revision: 671687
- rebuild for libunistring

* Tue Jul 15 2014 fwang <fwang> 0.19.2-1.mga5
+ Revision: 652810
- 0.19.2

* Tue Jun 10 2014 fwang <fwang> 0.19.1-1.mga5
+ Revision: 635364
- drop unused patch
- 0.19.1

* Mon Jun 09 2014 tv <tv> 0.19-2.mga5
+ Revision: 634948
- be less strict when checking translation catalogs so that we do not break other package builds
+ fwang <fwang>
- drop unused patches

* Tue Jun 03 2014 fwang <fwang> 0.19-1.mga5
+ Revision: 631815
- disable patch9
- drop str fmt
- 0.19

* Fri Feb 07 2014 fwang <fwang> 0.18.3.2-1.mga5
+ Revision: 585048
- add str fmt fix
- 0.18.3.2

* Sat Oct 19 2013 umeabot <umeabot> 0.18.3.1-2.mga4
+ Revision: 532116
- Mageia 4 Mass Rebuild

* Sat Aug 17 2013 fwang <fwang> 0.18.3.1-1.mga4
+ Revision: 467077
- new version 0.18.3.1

* Mon Jul 08 2013 fwang <fwang> 0.18.3-1.mga4
+ Revision: 451100
- new version 0.18.3

* Fri May 24 2013 luigiwalser <luigiwalser> 0.18.2.1-1.mga4
+ Revision: 426834
- re-diff patch 9
- 0.18.2.1

* Sat Jan 12 2013 cjw <cjw> 0.18.2-2.mga3
+ Revision: 352137
- path11: fix tests
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Dec 26 2012 fwang <fwang> 0.18.2-1.mga3
+ Revision: 335312
- fix typo
- new version 0.18.2

* Sat Jul 21 2012 colin <colin> 0.18.1.1-3.mga3
+ Revision: 273166
- Fix build with glibc-2.16 (patch originally from Gentoo)
- Update for usrmove

* Thu May 05 2011 ahmad <ahmad> 0.18.1.1-2.mga2
+ Revision: 95178
- Build with --disable-static and --disable-rpath
- Don't ship .la
- Fix the License tag(s) (Fedora)
+ rtp <rtp>
- allow to build gettext without emacs/cvs/libcroco

* Sat Jan 08 2011 blino <blino> 0.18.1.1-1.mga1
+ Revision: 369
- remove obsolete stuff
- imported package gettext


* Fri Jul 09 2010 Funda Wang <fwang@mandriva.org> 0.18.1.1-1mdv2011.0
+ Revision: 549878
- New version 0.18.1.1

* Thu Apr 29 2010 Christophe Fergeau <cfergeau@mandriva.com> 0.17-9mdv2010.1
+ Revision: 540832
- rebuild so that shared libraries are properly stripped again

* Wed Apr 28 2010 Christophe Fergeau <cfergeau@mandriva.com> 0.17-8mdv2010.1
+ Revision: 540340
- rebuild so that shared libraries are properly stripped again

* Wed Apr 28 2010 Christophe Fergeau <cfergeau@mandriva.com> 0.17-7mdv2010.1
+ Revision: 540026
- rebuild so that shared libraries are properly stripped again

* Sun Mar 14 2010 Oden Eriksson <oeriksson@mandriva.com> 0.17-6mdv2010.1
+ Revision: 519004
- rebuild

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 0.17-5mdv2010.0
+ Revision: 424835
- rebuild

* Sat Dec 20 2008 Oden Eriksson <oeriksson@mandriva.com> 0.17-4mdv2009.1
+ Revision: 316753
- added some more -Werror=format-security fixes
- fix build with -Werror=format-security (P8)
- added some required conditional spec file voodoo magic

* Sun Jun 29 2008 Oden Eriksson <oeriksson@mandriva.com> 0.17-3mdv2009.0
+ Revision: 229927
- added P7 from fedora to make it build with glibc28

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - kill re-definition of %%buildroot on Pixel's request
    - move HTML doc in devel sub package

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Sat Nov 10 2007 Funda Wang <fwang@mandriva.org> 0.17-1mdv2008.1
+ Revision: 107431
- fix file list
- drop old gettext-tools fr translation.
- New version 0.17

* Wed Sep 26 2007 Funda Wang <fwang@mandriva.org> 0.16.1-4mdv2008.0
+ Revision: 93043
- fix building by adding BR

* Thu Jun 07 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 0.16.1-3mdv2008.0
+ Revision: 36885
- rebuild for expat

* Sun May 27 2007 Funda Wang <fwang@mandriva.org> 0.16.1-2mdv2008.0
+ Revision: 31725
- gettext-devel (autopoint) requires cvs to work


* Thu Feb 08 2007 Thierry Vignaud <tvignaud@mandriva.com> 0.16.1-1mdv2007.0
+ Revision: 118110
- update sig
- new release

  + Gwenole Beauchesne <gbeauchesne@mandriva.com>

* Fri Jan 12 2007 Nicolas Lécureuil <neoclust@mandriva.org> 0.16-3mdv2007.1
+ Revision: 107741
- Build w/o java support
- Fix file list when builded w/o java
- Fix Provides

  + Thierry Vignaud <tvignaud@mandriva.com>
    - fix build
    - simplif doble buildrequire
    - fix buildrequires for test suite
    - parallel build is currently broken
    - update file list for 0.16
    - new release
    - major was bumped
    - new release

* Tue Oct 31 2006 Oden Eriksson <oeriksson@mandriva.com> 0.14.6-5mdv2007.1
+ Revision: 74673
- rebuild
- bzip2 cleanup
- fix build for the java stuff
- rebuild
- bunzip patches
- Import gettext

* Thu Jun 29 2006 Thierry Vignaud <tvignaud@mandriva.com> 0.14.6-1mdv2007.0
- new release
- rediff patch 2
- fix running test suite in a l10n environment
- move autopoint in the devel sub package (#22553)
- patch 6: workaround broken testsuite

* Sat Aug 13 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.14.5-2mdk
- build --disabled-shared autoconf-lib-link tests --with-pic

* Mon Jul 04 2005 Abel Cheung <deaddog@mandriva.org> 0.14.5-1mdk
- New release

* Sun Apr 17 2005 Abel Cheung <deaddog@mandriva.org> 0.14.4-1mdk
- New version
- Not applying libtool x86_64 patch for now, looks like bundled libtool
  (1.5.14) has x86_64 support
- Rediff patch5
- Remove patch6 (similar fix upstream), patch7 (upstream)
- S3: Use alternative french translation (#14341)

* Fri Nov 26 2004 Abel Cheung <deaddog@mandrake.org> 0.14.1-10mdk
- P6: fix CAN-2004-0966 (scripts allow symlink attack on temp files)
- P7: assorted CVS fixes
- Split C# stuff into another package if people really compile RPM with C# support

* Tue Sep 21 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.14.1-9mdk
- fix buildrequires (automake1.7 -> automake1.8)

* Wed Jul 28 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.14.1-8mdk
- merge from amd64-branch: fix broken built-in libtool

* Fri Jun 04 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.14.1-7mdk
- rebuild against gcc3.4

* Tue Jun 01 2004 Götz Waschk <waschk@linux-mandrake.com> 0.14.1-6mdk
- fix emacs site-start file

* Sun May 23 2004 Abel Cheung <deaddog@deaddog.org> 0.14.1-5mdk
- Drop patch0 (libtool) and patch1 (newer javac don't output error when
  copying class file onto itself anymore)
- Can optionally build C# support (using mono)

* Sat Apr 24 2004 Thierry Vignaud <tvignaud@mandrakesoft.com> 0.14.1-4mdk
- fix %%_libdir/libintl.so link

* Thu Apr 22 2004 Götz Waschk <waschk@linux-mandrake.com> 0.14.1-3mdk
- fix emacs site-start script

* Tue Apr 20 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 0.14.1-2mdk
- fix provides (from Charles A Edwards <eslrahc@bellsouth.net>)

* Mon Apr 19 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 0.14.1-1mdk
- 0.14.1
- bump major to 3
- nuke unpackaged files

